summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authork-paulius <k.dash.paulius@gmail.com>2016-02-14 14:51:29 -0600
committerk-paulius <k.dash.paulius@gmail.com>2016-02-14 14:51:29 -0600
commit448280c3be738304463cd2ae52c28238051f69da (patch)
treecbb585479b589ac55136d131e7234a203376166c /src
parent37abd83b64ac08d50076c8271aebf708e222b0ff (diff)
downloadpfsense-448280c3be738304463cd2ae52c28238051f69da.zip
pfsense-448280c3be738304463cd2ae52c28238051f69da.tar.gz
Rename NTP tab to Settings to be more user friendly.
Diffstat (limited to 'src')
-rw-r--r--src/etc/inc/priv.defs.inc4
-rw-r--r--src/usr/local/www/services_ntpd.php8
-rw-r--r--src/usr/local/www/services_ntpd_gps.php4
-rw-r--r--src/usr/local/www/services_ntpd_pps.php4
4 files changed, 10 insertions, 10 deletions
diff --git a/src/etc/inc/priv.defs.inc b/src/etc/inc/priv.defs.inc
index c54ab43..133ce6f 100644
--- a/src/etc/inc/priv.defs.inc
+++ b/src/etc/inc/priv.defs.inc
@@ -797,8 +797,8 @@ $priv_list['page-services-igmpproxy-edit']['match'] = array();
$priv_list['page-services-igmpproxy-edit']['match'][] = "services_igmpproxy_edit.php*";
$priv_list['page-services-ntpd'] = array();
-$priv_list['page-services-ntpd']['name'] = gettext("WebCfg - Services: NTP");
-$priv_list['page-services-ntpd']['descr'] = gettext("Allow access to the 'Services: NTP' page.");
+$priv_list['page-services-ntpd']['name'] = gettext("WebCfg - Services: NTP Settings");
+$priv_list['page-services-ntpd']['descr'] = gettext("Allow access to the 'Services: NTP Settings' page.");
$priv_list['page-services-ntpd']['match'] = array();
$priv_list['page-services-ntpd']['match'][] = "services_ntpd.php*";
diff --git a/src/usr/local/www/services_ntpd_gps.php b/src/usr/local/www/services_ntpd_gps.php
index 2781178..4ff9023 100644
--- a/src/usr/local/www/services_ntpd_gps.php
+++ b/src/usr/local/www/services_ntpd_gps.php
@@ -227,7 +227,7 @@ $shortcut_section = "ntp";
include("head.inc");
$tab_array = array();
-$tab_array[] = array(gettext("NTP"), false, "services_ntpd.php");
+$tab_array[] = array(gettext("Settings"), false, "services_ntpd.php");
$tab_array[] = array(gettext("Serial GPS"), true, "services_ntpd_gps.php");
$tab_array[] = array(gettext("PPS"), false, "services_ntpd_pps.php");
display_top_tabs($tab_array);
@@ -241,7 +241,7 @@ $section->addInput(new Form_StaticText(
'A GPS connected via a serial port may be used as a reference clock for NTP. If the GPS also supports PPS and is properly configured, ' .
'and connected, that GPS may also be used as a Pulse Per Second clock reference. NOTE: A USB GPS may work, but is not recommended due to USB bus timing issues.' . '<br />' .
'For the best results, NTP should have at least three sources of time. So it is best to configure at least 2 servers under ' .
- '<a href="services_ntpd.php">Services > NTP</a>' .
+ '<a href="services_ntpd.php">Services > NTP > Settings</a>' .
' to minimize clock drift if the GPS data is not valid over time. Otherwise ntpd may only use values from the unsynchronized local clock when providing time to clients.'
));
diff --git a/src/usr/local/www/services_ntpd_pps.php b/src/usr/local/www/services_ntpd_pps.php
index b050168..2eedfbe 100644
--- a/src/usr/local/www/services_ntpd_pps.php
+++ b/src/usr/local/www/services_ntpd_pps.php
@@ -146,7 +146,7 @@ if ($savemsg) {
}
$tab_array = array();
-$tab_array[] = array(gettext("NTP"), false, "services_ntpd.php");
+$tab_array[] = array(gettext("Settings"), false, "services_ntpd.php");
$tab_array[] = array(gettext("Serial GPS"), false, "services_ntpd_gps.php");
$tab_array[] = array(gettext("PPS"), true, "services_ntpd_pps.php");
display_top_tabs($tab_array);
@@ -161,7 +161,7 @@ $section->addInput(new Form_StaticText(
'A serial GPS may also be used, but the serial GPS driver would usually be the better option. ' .
'A PPS signal only provides a reference to the change of a second, so at least one other source to number the seconds is required.' . '<br /><br />' .
'At least 3 additional time sources should be configured under ' .
- '<a href="services_ntpd.php">' . 'Services > NTP' . '</a>' . ' to reliably supply the time of each PPS pulse.'
+ '<a href="services_ntpd.php">' . 'Services > NTP > Settings' . '</a>' . ' to reliably supply the time of each PPS pulse.'
));
$serialports = glob("/dev/cua?[0-9]{,.[0-9]}", GLOB_BRACE);
OpenPOWER on IntegriCloud
diff --git a/src/usr/local/www/services_ntpd.php b/src/usr/local/www/services_ntpd.php
index e91545b..0f75d99 100644
--- a/src/usr/local/www/services_ntpd.php
+++ b/src/usr/local/www/services_ntpd.php
@@ -56,8 +56,8 @@
##|+PRIV
##|*IDENT=page-services-ntpd
##|*NAME=Services: NTP
##|*DESCR=Allow access to the 'Services: NTP' page.
##|*MATCH=services_ntpd.php*
##|-PRIV
@@ -251,7 +251,7 @@ if (empty($pconfig['interface'])) {
} else {
$pconfig['interface'] = explode(",", $pconfig['interface']);
}
-$pgtitle = array(gettext("Services"), gettext("NTP"), gettext("NTP"));
+$pgtitle = array(gettext("Services"), gettext("NTP"), gettext("Settings"));
$shortcut_section = "ntp";
include("head.inc");
@@ -263,7 +263,7 @@ if ($savemsg) {
}
$tab_array = array();
-$tab_array[] = array(gettext("NTP"), true, "services_ntpd.php");
+$tab_array[] = array(gettext("Settings"), true, "services_ntpd.php");
$tab_array[] = array(gettext("Serial GPS"), false, "services_ntpd_gps.php");
$tab_array[] = array(gettext("PPS"), false, "services_ntpd_pps.php");
display_top_tabs($tab_array);
@@ -56,8 +56,8 @@
##|+PRIV
##|*IDENT=page-services-ntpd
-##|*NAME=Services: NTP
-##|*DESCR=Allow access to the 'Services: NTP' page.
+##|*NAME=Services: NTP Settings
+##|*DESCR=Allow access to the 'Services: NTP Settings' page.
##|*MATCH=services_ntpd.php*
##|-PRIV